@@ -2,8 +2,9 @@ import logging
 
 import google.api_core.exceptions
 from google.cloud.pubsub_v1 import SubscriberClient
-from google.cloud.pubsub_v1.types import ExpirationPolicy, FieldMask, RetryPolicy
 from google.protobuf.duration_pb2 import Duration
+from google.protobuf.field_mask_pb2 import FieldMask
+from google.pubsub_v1.types.pubsub import ExpirationPolicy, RetryPolicy, Subscription as _Subscription
 
 
 logger = logging.getLogger(__name__)
@@ -56,11 +57,12 @@ class Subscription:
 
         # If expiration_time is None, the subscription will never expire.
         if expiration_time is None:
-            self.expiration_policy = ExpirationPolicy()
+            self.expiration_policy = ExpirationPolicy(mapping=None)
         else:
-            self.expiration_policy = ExpirationPolicy(ttl=Duration(seconds=expiration_time))
+            self.expiration_policy = ExpirationPolicy(mapping=None, ttl=Duration(seconds=expiration_time))
 
         self.retry_policy = RetryPolicy(
+            mapping=None,
             minimum_backoff=Duration(seconds=minimum_retry_backoff),
             maximum_backoff=Duration(seconds=maximum_retry_backoff),
         )
@@ -81,12 +83,12 @@ class Subscription:
         subscription = self._create_proto_message_subscription()
 
         if not allow_existing:
-            subscription = self.subscriber.create_subscription(**subscription)
+            subscription = self.subscriber.create_subscription(request=subscription)
             self._log_creation()
             return subscription
 
         try:
-            subscription = self.subscriber.create_subscription(**subscription)
+            subscription = self.subscriber.create_subscription(request=subscription)
         except google.api_core.exceptions.AlreadyExists:
             pass
 
@@ -133,13 +135,14 @@ class Subscription:
     def _create_proto_message_subscription(self):
         """Create a Proto message subscription from the instance to be sent to the Pub/Sub API.
 
-        :return dict:
+        :return google.pubsub_v1.types.pubsub.Subscription:
         """
-        return {
-            "name": self.path,
-            "topic": self.topic.path,
-            "ack_deadline_seconds": self.ack_deadline,
-            "message_retention_duration": self.message_retention_duration,
-            "expiration_policy": self.expiration_policy,
-            "retry_policy": self.retry_policy,
-        }
+        return _Subscription(
+            mapping=None,
+            name=self.path,
+            topic=self.topic.path,
+            ack_deadline_seconds=self.ack_deadline,  # noqa
+            message_retention_duration=self.message_retention_duration,  # noqa
+            expiration_policy=self.expiration_policy,  # noqa
+            retry_policy=self.retry_policy,  # noqa
+        )
