@@ -498,7 +498,7 @@ class TestService(BaseTestCase):
             Datafile(path="gs://my-dataset/goodbye.csv", project_name="blah", hypothetical=True),
         ]
 
-        input_manifest = Manifest(datasets=[Dataset(files=files)], path="gs://my-dataset", keys={"my_dataset": 0})
+        input_manifest = Manifest(datasets={"my-dataset": Dataset(files=files)}, path="gs://my-dataset")
 
         with patch("octue.cloud.pub_sub.service.Topic", new=MockTopic):
             with patch("octue.cloud.pub_sub.service.Subscription", new=MockSubscription):
@@ -529,7 +529,7 @@ class TestService(BaseTestCase):
             Datafile(path="gs://my-dataset/goodbye.csv", project_name=TEST_PROJECT_NAME, hypothetical=True),
         ]
 
-        input_manifest = Manifest(datasets=[Dataset(files=files)], path="gs://my-dataset", keys={"my_dataset": 0})
+        input_manifest = Manifest(datasets={"my-dataset": Dataset(files=files)}, path="gs://my-dataset")
 
         with patch("octue.cloud.pub_sub.service.Topic", new=MockTopic):
             with patch("octue.cloud.pub_sub.service.Subscription", new=MockSubscription):
@@ -556,7 +556,7 @@ class TestService(BaseTestCase):
             MockService(backend=BACKEND).ask(
                 service_id=str(uuid.uuid4()),
                 input_values={},
-                input_manifest=Manifest(),
+                input_manifest=self.create_valid_manifest(),
             )
 
     def test_ask_with_input_manifest_with_local_paths_works_if_allowed_and_child_has_access_to_the_local_paths(self):
@@ -571,7 +571,7 @@ class TestService(BaseTestCase):
         local_file = Datafile(path=temporary_local_path)
         self.assertFalse(local_file.exists_in_cloud)
 
-        manifest = Manifest(datasets=[Dataset(name="my-local-dataset", file=local_file)], keys={0: "my-local-dataset"})
+        manifest = Manifest(datasets={"my-local-dataset": Dataset(name="my-local-dataset", file=local_file)})
 
         # Get the child to open the local file itself and return the contents as output.
         def run_function(analysis_id, input_values, input_manifest, analysis_log_handler, handle_monitor_message):
